@@ -26,6 +26,10 @@ TIME_FMT = (
     "([A-Z][A-Z][A-Z]) ([0-9]+) ([1-2][0-9][0-9][0-9])"
 )
 TIME_RE = re.compile(f"^{TIME_FMT}$", re.M | re.IGNORECASE)
+TIME_UTC_RE = re.compile(
+    TIME_FMT.replace("(AM|PM) ([A-Z][A-Z][A-Z]?T)", r"(AM|PM)?\s?(UTC)"),
+    re.M | re.I,
+)
 # Sometimes products have a duplicated timestamp in another tz
 TIME_EXT_RE = re.compile(
     rf"^{TIME_FMT}\s?/\s?{TIME_FMT}\s?/$", re.M | re.IGNORECASE
@@ -54,20 +58,27 @@ WINDHAIL = re.compile(
     "(?P<windunits>MPH|KTS) "
     r"(?P<haildir>[><]?)(?P<hail>[0-9\.]+)IN"
 )
-HAILTAG = re.compile(r".*HAIL\.\.\.(?P<haildir>[><]?)(?P<hail>[0-9\.]+)IN")
+HAILTAG = re.compile(
+    r".*(HAIL|MAX HAIL SIZE)\.\.\.(?P<haildir>[><]?)(?P<hail>[0-9\.]+)\s?IN"
+)
 WINDTAG = re.compile(
-    r".*WIND\.\.\.(?P<winddir>[><]?)\s?(?P<wind>[0-9]+)\s?"
+    r".*(WIND|MAX WIND GUST)\.\.\.(?P<winddir>[><]?)\s?(?P<wind>[0-9]+)\s?"
     "(?P<windunits>MPH|KTS)"
 )
 TORNADOTAG = re.compile(
     r".*TORNADO\.\.\.(?P<tornado>RADAR INDICATED|" "OBSERVED|POSSIBLE)"
 )
-WATERSPOUTTAG = re.compile(
-    r".*WATERSPOUT\.\.\.(?P<waterspout>RADAR INDICATED|OBSERVED|POSSIBLE)"
+SPOUTTAG = re.compile(
+    r".*(?P<species>LAND|WATER)SPOUT\.\.\."
+    "(?P<spout>RADAR INDICATED|OBSERVED|POSSIBLE)"
 )
-TORNADODAMAGETAG = re.compile(
-    r".*TORNADO DAMAGE THREAT\.\.\."
-    "(?P<damage>CONSIDERABLE|SIGNIFICANT|CATASTROPHIC)"
+DAMAGETAG = re.compile(
+    r".*(?P<species>TORNADO|THUNDERSTORM) DAMAGE THREAT\.\.\."
+    "(?P<damage>CONSIDERABLE|SIGNIFICANT|CATASTROPHIC|DESTRUCTIVE)"
+)
+THREATTAG = re.compile(
+    r"(?P<species>HAIL|WIND) THREAT\.\.\."
+    r"(?P<tag>RADAR INDICATED|OBSERVED|POSSIBLE)"
 )
 FLOOD_TAGS = re.compile(
     r".*(?P<key>FLASH FLOOD|FLASH FLOOD DAMAGE THREAT|EXPECTED RAINFALL|"
@@ -137,6 +148,7 @@ def date_tokens2datetime(tokens):
       tz (datetime.timezone): of this product
       utcvalid (datetimetz): of this product
     """
+    tokens = list(tokens)  # ensure mutable
     z = tokens[2].upper()
     tz = ZoneInfo(reference.name2pytz.get(z, "UTC"))
     hhmi = tokens[0]
@@ -152,12 +164,16 @@ def date_tokens2datetime(tokens):
         hh = hhmi[:-2]
         mi = hhmi[-2:]
     # Workaround 24 hour clock abuse
-    if int(hh) > 12 and tokens[1].upper() == "PM":
+    if int(hh) > 12 and (
+        tokens[1].upper() == "PM" or tokens[2] in ["UTC", "GMT"]
+    ):
+        # this is a hack to ensure this is PM when we are in UTC
+        tokens[1] = "PM"
         hh = int(hh) - 12
     dstr = "%s:%s %s %s %s %s" % (
-        hh,
+        hh if int(hh) > 0 else 12,
         mi,
-        tokens[1],
+        tokens[1] if tokens[1] != "" else "AM",
         tokens[4],
         tokens[5],
         tokens[6],
@@ -180,7 +196,7 @@ class TextProductSegment:
         )
         self.vtec = vtec.parse(text)
         self.headlines = self.parse_headlines()
-        self.hvtec = hvtec.parse(text, nwsli_provider=tp.nwsli_provider)
+        self.hvtec = hvtec.parse(text, tp=tp)
 
         # TIME...MOT...LOC Stuff!
         self.tml_giswkt = None
@@ -196,12 +212,15 @@ class TextProductSegment:
         # tags
         self.windtag = None
         self.windtagunits = None
+        self.windthreat = None
         self.hailtag = None
         self.haildirtag = None
+        self.hailthreat = None
         self.winddirtag = None
         self.tornadotag = None
         self.waterspouttag = None
-        self.tornadodamagetag = None
+        self.landspouttag = None
+        self.damagetag = None
         # allows for deterministic testing of results
         self.flood_tags = OrderedDict()
         self.is_emergency = False
@@ -295,15 +314,24 @@ class TextProductSegment:
             gdict = match.groupdict()
             self.tornadotag = gdict["tornado"]
 
-        match = TORNADODAMAGETAG.match(nolf)
+        match = DAMAGETAG.match(nolf)
         if match:
             gdict = match.groupdict()
-            self.tornadodamagetag = gdict["damage"]
+            self.damagetag = gdict["damage"]
 
-        match = WATERSPOUTTAG.match(nolf)
+        for (species, tag) in THREATTAG.findall(nolf):
+            if species == "HAIL":
+                self.hailthreat = tag
+            elif species == "WIND":
+                self.windthreat = tag
+
+        match = SPOUTTAG.match(nolf)
         if match:
             gdict = match.groupdict()
-            self.waterspouttag = gdict["waterspout"]
+            if gdict["species"] == "WATER":
+                self.waterspouttag = gdict["spout"]
+            else:
+                self.landspouttag = gdict["spout"]
 
         for token in FLOOD_TAGS.findall(self.unixtext):
             self.flood_tags[token[0]] = token[1]
@@ -317,8 +345,9 @@ class TextProductSegment:
                 self.windtag is None,
                 self.tornadotag is None,
                 self.hailtag is None,
-                self.tornadodamagetag is None,
+                self.damagetag is None,
                 self.waterspouttag is None,
+                self.landspouttag is None,
                 not self.flood_tags,
             ]
         ):
@@ -329,23 +358,27 @@ class TextProductSegment:
             parts.append("tornado: %s" % (self.tornadotag))
         if self.waterspouttag is not None:
             parts.append("waterspout: %s" % (self.waterspouttag))
-        if self.tornadodamagetag is not None:
-            parts.append("tornado damage threat: %s" % (self.tornadodamagetag))
+        if self.landspouttag is not None:
+            parts.append("landspout: %s" % (self.landspouttag))
+        if self.damagetag is not None:
+            parts.append("damage threat: %s" % (self.damagetag))
         if self.windtag is not None:
             parts.append(
-                "wind: %s%s %s"
+                "wind: %s%s %s%s"
                 % (
                     self.winddirtag.replace(">", "&gt;").replace("<", "&lt;"),
                     self.windtag,
                     self.windtagunits,
+                    "" if self.windthreat is None else f" ({self.windthreat})",
                 )
             )
         if self.hailtag is not None:
             parts.append(
-                "hail: %s%s IN"
+                "hail: %s%s IN%s"
                 % (
                     self.haildirtag.replace(">", "&gt;").replace("<", "&lt;"),
                     self.hailtag,
+                    "" if self.hailthreat is None else f" ({self.hailthreat})",
                 )
             )
         for k, v in self.flood_tags.items():
@@ -378,10 +411,21 @@ class TextProductSegment:
 
         # check 1, is the polygon valid?
         if not poly.is_valid:
+            poly = poly.buffer(0)
+            # Careful, this could return a multipolygon
+            if isinstance(poly, MultiPolygon):
+                self.tp.warnings.append(
+                    "LAT...LON buffer(0) returned multipolygon, culling."
+                )
+                return None
+            if not poly.is_valid:
+                self.tp.warnings.append(
+                    f"LAT...LON polygon is invalid twice!\n{poly.exterior.xy}"
+                )
+                return None
             self.tp.warnings.append(
-                ("LAT...LON polygon is invalid!\n%s") % (poly.exterior.xy,)
+                "LAT...LON polygon is invalid, but buffer(0) fixed it!"
             )
-            return None
         # check 2, is the exterior ring of the polygon clockwise?
         if poly.exterior.is_ccw:
             # No longer a warning as it was too much noise
@@ -665,17 +709,19 @@ class TextProduct:
             tokens = TIME_EXT_RE.findall(self.unixtext)
             if not tokens:
                 tokens = TIME_RE_ANYWHERE.findall(self.unixtext)
+                if not tokens:
+                    tokens = TIME_UTC_RE.findall(self.unixtext)
         if provided_utcnow is None and tokens:
             try:
                 z, _tz, valid = date_tokens2datetime(tokens[0])
                 if z not in reference.offsets:
                     self.warnings.append(f"product timezone '{z}' unknown")
-            except ValueError:
+            except ValueError as exp:
                 msg = (
                     "Invalid timestamp [%s] found in product "
                     "[%s %s %s] header"
                 ) % (" ".join(tokens[0]), self.wmo, self.source, self.afos)
-                raise TextProductException(self.source[1:], msg)
+                raise TextProductException(self.source[1:], msg) from exp
 
             # Set the utcnow based on what we found by looking at the header
             self.utcnow = valid
