@@ -129,6 +129,14 @@ def trace_r(val):
     return val
 
 
+def get_number_year(text):
+    """Ensure we get a year that makes sense."""
+    val = get_number(text)
+    if val is None or val < 1700 or val > (datetime.date.today().year + 1):
+        return None
+    return val
+
+
 def get_number(text):
     """ Convert a string into a number, preferable a float! """
     if text is None:
@@ -199,23 +207,25 @@ def parse_snowfall(regime, lines, data):
         if key == "SNOW DEPTH":
             continue
         key = convert_key(key)
-        data["snow_%s" % (key,)] = get_number(tokens[1])
-        data["snow_%s_record" % (key,)] = get_number(tokens[3])
-        yeartest = get_number(tokens[4])
+        data[f"snow_{key}"] = get_number(tokens[1])
+        data[f"snow_{key}_record"] = get_number(tokens[3])
+        yeartest = get_number_year(tokens[4])
         if yeartest is not None:
-            data["snow_%s_record_years" % (key,)] = [yeartest]
-        data["snow_%s_normal" % (key,)] = get_number(tokens[5])
-        data["snow_%s_departure" % (key,)] = get_number(tokens[6])
-        data["snow_%s_last" % (key,)] = get_number(tokens[7])
+            data[f"snow_{key}_record_years"] = [yeartest]
+        data[f"snow_{key}_normal"] = get_number(tokens[5])
+        data[f"snow_{key}_departure"] = get_number(tokens[6])
+        data[f"snow_{key}_last"] = get_number(tokens[7])
         if (
             key == "today"
             and yeartest is not None
-            and data["snow_%s_record_years" % (key,)][0] is not None
+            and data[f"snow_{key}_record_years"][0] is not None
         ):
             while (linenum + 1) < len(lines) and len(
                 lines[linenum + 1].strip()
             ) == 4:
-                data["snow_today_record_years"].append(int(lines[linenum + 1]))
+                n = get_number_year(lines[linenum + 1])
+                if n is not None:
+                    data["snow_today_record_years"].append(n)
                 linenum += 1
 
 
@@ -229,56 +239,65 @@ def parse_precipitation(regime, lines, data):
         if key is None:
             continue
 
-        data["precip_%s" % (key,)] = get_number(tokens[1])
-        data["precip_%s_record" % (key,)] = get_number(tokens[3])
-        yeartest = get_number(tokens[4])
+        data[f"precip_{key}"] = get_number(tokens[1])
+        data[f"precip_{key}_record"] = get_number(tokens[3])
+        yeartest = get_number_year(tokens[4])
         if yeartest is not None:
-            data["precip_%s_record_years" % (key,)] = [yeartest]
-        data["precip_%s_normal" % (key,)] = get_number(tokens[5])
-        data["precip_%s_departure" % (key,)] = get_number(tokens[6])
-        data["precip_%s_last" % (key,)] = get_number(tokens[7])
+            data[f"precip_{key}_record_years"] = [yeartest]
+        data[f"precip_{key}_normal"] = get_number(tokens[5])
+        data[f"precip_{key}_departure"] = get_number(tokens[6])
+        data[f"precip_{key}_last"] = get_number(tokens[7])
         if (
             key == "today"
             and yeartest is not None
-            and data["precip_%s_record_years" % (key,)][0] is not None
+            and data[f"precip_{key}_record_years"][0] is not None
         ):
             while (linenum + 1) < len(lines) and len(
                 lines[linenum + 1].strip()
             ) == 4:
-                data["precip_today_record_years"].append(
-                    int(lines[linenum + 1])
-                )
+                n = get_number_year(lines[linenum + 1])
+                if n is not None:
+                    data["precip_today_record_years"].append(n)
                 linenum += 1
 
 
-def parse_temperature(regime, lines, data):
+def parse_temperature(prod, regime, lines, data):
     """Here we parse a temperature section"""
     for linenum, line in enumerate(lines):
         if len(line.strip()) < 18:
             continue
+        # Repair a broken (E) product, see akrherz/pyIEM#08
+        if line[20:23] == "(E)" and line[38] == " ":
+            prod.warnings.append(f"Invalid line repaired |{line}|")
+            line = line.replace("(E)", "E ")
         tokens = make_tokens(regime, line)
         key = tokens[0].strip().lower()
         if key.upper() not in ["MAXIMUM", "MINIMUM", "AVERAGE"]:
             continue
-        data["temperature_%s" % (key,)] = get_number(tokens[1])
+        data[f"temperature_{key}"] = get_number(tokens[1])
         if tokens[2] is not None:
-            data["temperature_%s_time" % (key,)] = tokens[2]
+            data[f"temperature_{key}_time"] = tokens[2]
         if tokens[3] is not None:
-            data["temperature_%s_record" % (key,)] = get_number(tokens[3])
-        if tokens[4] is not None:
-            n = get_number(tokens[4])
+            data[f"temperature_{key}_record"] = get_number(tokens[3])
+        if tokens[4] is not None and tokens[4].strip() not in ["", "M", "MM"]:
+            n = get_number_year(tokens[4])
             if n is not None:
-                data["temperature_%s_record_years" % (key,)] = [n]
+                data[f"temperature_{key}_record_years"] = [n]
+            else:
+                prod.warnings.append(f"Found invalid year |{tokens[4]}|")
         if tokens[5] is not None:
-            data["temperature_%s_normal" % (key,)] = get_number(tokens[5])
-            # Check next line(s) for more years
-            while (linenum + 1) < len(lines) and len(
-                lines[linenum + 1].strip()
-            ) == 4:
-                data["temperature_%s_record_years" % (key,)].append(
-                    int(lines[linenum + 1])
-                )
-                linenum += 1
+            data[f"temperature_{key}_normal"] = get_number(tokens[5])
+        # Check next line(s) for more years
+        while (linenum + 1) < len(lines) and len(
+            lines[linenum + 1].strip()
+        ) == 4:
+            line2 = lines[linenum + 1].strip()
+            n = get_number_year(line2)
+            if n is not None:
+                data[f"temperature_{key}_record_years"].append(n)
+            else:
+                prod.warnings.append(f"Found invalid year |{line2}|")
+            linenum += 1
 
 
 def parse_sky_coverage(lines, data):
@@ -292,6 +311,15 @@ def parse_sky_coverage(lines, data):
                 pass
 
 
+def parse_headline(section):
+    """ Figure out when this product is valid for """
+    tokens = HEADLINE_RE.findall(section.replace("\n", " "))
+    myfmt = "%b %d %Y" if len(tokens[0][1].split()[0]) == 3 else "%B %d %Y"
+    cli_valid = datetime.datetime.strptime(tokens[0][1], myfmt).date()
+    cli_station = (tokens[0][0]).strip().upper()
+    return (cli_valid, cli_station)
+
+
 def parse_wind(lines, data):
     """Parse any wind information."""
     # hold your nose here
@@ -316,21 +344,21 @@ def _compute_station_ids(prod, cli_station_name, is_multi):
                 break
         if station is None:
             raise CLIException(
-                "Unknown CLI Station Text: |%s|" % (cli_station_name,)
+                f"Unknown CLI Station Text: |{cli_station_name}|"
             )
     else:
         station = prod.source[0] + prod.afos[3:]
     # We have computed a four character station ID, is it known?
     if station not in prod.nwsli_provider:
         prod.warnings.append(
-            "Station not known to NWSCLI Network |%s|" % (station,)
+            f"Station not known to NWSCLI Network |{station}|"
         )
         return station, None, None
 
     access_station = None
     access_network = None
     # See if our network table provides an attribute that maps us to an ASOS
-    val = prod.nwsli_provider[station].get("attributes", dict()).get("MAPS_TO")
+    val = prod.nwsli_provider[station].get("attributes", {}).get("MAPS_TO")
     if val is not None:
         tokens = val.split("|")
         if len(tokens) == 2:
@@ -338,13 +366,96 @@ def _compute_station_ids(prod, cli_station_name, is_multi):
     if access_station is None:
         # Our default mapping
         access_station = station[1:] if station.startswith("K") else station
-        access_network = "%s_ASOS" % (
-            prod.nwsli_provider[station].get("state"),
-        )
+        access_network = f"{prod.nwsli_provider[station].get('state')}_ASOS"
 
     return station, access_station, access_network
 
 
+def sql_data(prod, cursor, data):
+    """Do an individual data entry."""
+    # See what we currently have stored.
+    cursor.execute(
+        "SELECT product from cli_data where station = %s and valid = %s",
+        (data["db_station"], data["cli_valid"]),
+    )
+    if cursor.rowcount == 1:
+        row = cursor.fetchone()
+        pid = row["product"]
+        if pid is not None and prod.get_product_id() < pid:
+            return
+        cursor.execute(
+            "DELETE from cli_data WHERE station = %s and valid = %s",
+            (data["db_station"], data["cli_valid"]),
+        )
+    dd = data["data"]
+    cursor.execute(
+        """
+        INSERT into cli_data(station, product, valid, high, high_normal,
+        high_record, high_record_years, low, low_normal, low_record,
+        low_record_years, precip, precip_month, precip_jan1, precip_jul1,
+        precip_normal, precip_record, precip_record_years, precip_month_normal,
+        snow, snow_month, snow_jun1, snow_jul1, snow_normal, snow_dec1,
+        precip_dec1, precip_dec1_normal, precip_jan1_normal, high_time,
+        low_time, snow_record_years, snow_record, snow_jun1_normal,
+        snow_jul1_normal, snow_dec1_normal, snow_month_normal, precip_jun1,
+        precip_jun1_normal, average_sky_cover, resultant_wind_speed,
+        resultant_wind_direction, highest_wind_speed, highest_wind_direction,
+        highest_gust_speed, highest_gust_direction, average_wind_speed)
+        VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s,
+        %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s,
+        %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s)
+        """,
+        (
+            data["db_station"],
+            prod.get_product_id(),
+            data["cli_valid"],
+            dd.get("temperature_maximum"),
+            dd.get("temperature_maximum_normal"),
+            dd.get("temperature_maximum_record"),
+            dd.get("temperature_maximum_record_years", []),
+            dd.get("temperature_minimum"),
+            dd.get("temperature_minimum_normal"),
+            dd.get("temperature_minimum_record"),
+            dd.get("temperature_minimum_record_years", []),
+            dd.get("precip_today"),
+            dd.get("precip_month"),
+            dd.get("precip_jan1"),
+            dd.get("precip_jul1"),
+            dd.get("precip_today_normal"),
+            dd.get("precip_today_record"),
+            dd.get("precip_today_record_years", []),
+            dd.get("precip_month_normal"),
+            dd.get("snow_today"),
+            dd.get("snow_month"),
+            dd.get("snow_jun1"),
+            dd.get("snow_jul1"),
+            dd.get("snow_today_normal"),
+            dd.get("snow_dec1"),
+            dd.get("precip_dec1"),
+            dd.get("precip_dec1_normal"),
+            dd.get("precip_jan1_normal"),
+            dd.get("temperature_maximum_time"),
+            dd.get("temperature_minimum_time"),
+            dd.get("snow_today_record_years", []),
+            dd.get("snow_today_record"),
+            dd.get("snow_jun1_normal"),
+            dd.get("snow_jul1_normal"),
+            dd.get("snow_dec1_normal"),
+            dd.get("snow_month_normal"),
+            dd.get("precip_jun1"),
+            dd.get("precip_jun1_normal"),
+            dd.get("average_sky_cover"),
+            dd.get("resultant_wind_speed"),
+            dd.get("resultant_wind_direction"),
+            dd.get("highest_wind_speed"),
+            dd.get("highest_wind_direction"),
+            dd.get("highest_gust_speed"),
+            dd.get("highest_gust_direction"),
+            dd.get("average_wind_speed"),
+        ),
+    )
+
+
 class CLIProduct(TextProduct):
     """
     Represents a CLI Daily Climate Report Product
@@ -370,9 +481,7 @@ class CLIProduct(TextProduct):
             # We have meat!
             self.compute_diction(section)
             entry = {}
-            entry["cli_valid"], entry["cli_station"] = self.parse_cli_headline(
-                section
-            )
+            entry["cli_valid"], entry["cli_station"] = parse_headline(section)
             (
                 entry["db_station"],
                 entry["access_station"],
@@ -418,58 +527,54 @@ class CLIProduct(TextProduct):
         diction = tokens[0].strip()
         if diction not in REGIMES:
             raise CLIException(
-                "Unknown diction found in 'WEATHER ITEM'\n|%s|" % (diction,)
+                f"Unknown diction found in 'WEATHER ITEM'\n|{diction}|"
             )
 
         self.regime = REGIMES.index(diction)
 
     def get_jabbers(self, uri, _=None):
         """ Override the jabber message formatter """
-        url = "%s?pid=%s" % (uri, self.get_product_id())
+        url = f"{uri}?pid={self.get_product_id()}"
         res = []
+        xtra = {
+            "channels": self.get_channels(),
+            "product_id": self.get_product_id(),
+        }
         for data in self.data:
-            mess = (
-                "%s %s Climate Report: High: %s Low: %s "
-                "Precip: %s Snow: %s %s"
-            ) % (
-                data["cli_station"],
-                data["cli_valid"].strftime("%b %-d"),
-                data["data"].get("temperature_maximum", "M"),
-                data["data"].get("temperature_minimum", "M"),
-                trace_r(data["data"].get("precip_today", "M")),
-                trace_r(data["data"].get("snow_today", "M")),
-                url,
-            )
-            htmlmess = (
-                '%s <a href="%s">%s Climate Report</a>: High: %s '
-                "Low: %s Precip: %s Snow: %s"
-            ) % (
-                data["cli_station"],
-                url,
-                data["cli_valid"].strftime("%b %-d"),
+            msg = "High: %s Low: %s Precip: %s Snow: %s" % (
                 data["data"].get("temperature_maximum", "M"),
                 data["data"].get("temperature_minimum", "M"),
                 trace_r(data["data"].get("precip_today", "M")),
                 trace_r(data["data"].get("snow_today", "M")),
             )
-            tweet = ("%s %s Climate: Hi: %s Lo: %s Precip: %s Snow: %s %s") % (
+            mess = ("%s %s Climate Report: %s %s") % (
                 data["cli_station"],
                 data["cli_valid"].strftime("%b %-d"),
-                data["data"].get("temperature_maximum", "M"),
-                data["data"].get("temperature_minimum", "M"),
-                trace_r(data["data"].get("precip_today", "M")),
-                trace_r(data["data"].get("snow_today", "M")),
+                msg,
+                url,
+            )
+            htmlmess = ('%s <a href="%s">%s Climate Report</a>: %s') % (
+                data["cli_station"],
+                url,
+                data["cli_valid"].strftime("%b %-d"),
+                msg,
+            )
+            xtra["twitter_media"] = (
+                "https://mesonet.agron.iastate.edu/plotting/auto/plot/218/"
+                f"network:NWSCLI::station:{data['db_station']}::"
+                f"date:{data['cli_valid'].strftime('%Y-%m-%d')}.png"
+            )
+            xtra["twitter"] = ("%s %s Climate: %s %s") % (
+                data["cli_station"],
+                data["cli_valid"].strftime("%b %-d"),
+                msg,
                 url,
             )
             res.append(
                 [
                     mess.replace(str(TRACE_VALUE), "Trace"),
                     htmlmess.replace(str(TRACE_VALUE), "Trace"),
-                    {
-                        "channels": self.get_channels(),
-                        "product_id": self.get_product_id(),
-                        "twitter": tweet,
-                    },
+                    xtra,
                 ]
             )
         return res
@@ -477,10 +582,13 @@ class CLIProduct(TextProduct):
     def parse_data(self, section):
         """ Actually do the parsing of this silly format """
         data = {}
-        pos = section.find("TEMPERATURE")
-        if pos == -1:
+        # We need to first search down the section to look for where the
+        # first TEMPERATURE section starts.
+        regex = re.compile("^TEMPERATURE", re.M)
+        search = regex.search(section)
+        if search is None:
             raise CLIException("Failed to find TEMPERATURE, aborting")
-
+        pos = search.start()
         # Strip extraneous spaces
         meat = "\n".join([s.rstrip() for s in section[pos:].split("\n")])
         # replace any 2+ \n with just two
@@ -489,7 +597,7 @@ class CLIProduct(TextProduct):
         for _section in sections:
             lines = _section.split("\n")
             if lines[0] in ["TEMPERATURE (F)", "TEMPERATURE"]:
-                parse_temperature(self.regime, lines, data)
+                parse_temperature(self, self.regime, lines, data)
             elif lines[0] in ["PRECIPITATION (IN)", "PRECIPITATION"]:
                 parse_precipitation(self.regime, lines, data)
             elif lines[0] in ["SNOWFALL (IN)", "SNOWFALL"]:
@@ -501,119 +609,10 @@ class CLIProduct(TextProduct):
 
         return data
 
-    def parse_cli_headline(self, section):
-        """ Figure out when this product is valid for """
-        tokens = HEADLINE_RE.findall(section.replace("\n", " "))
-        if len(tokens[0][1].split()[0]) == 3:
-            myfmt = "%b %d %Y"
-        else:
-            myfmt = "%B %d %Y"
-        cli_valid = datetime.datetime.strptime(tokens[0][1], myfmt).date()
-        cli_station = (tokens[0][0]).strip().upper()
-        return (cli_valid, cli_station)
-
-    def _sql_data(self, cursor, data):
-        """Do an individual data entry."""
-        # See what we currently have stored.
-        cursor.execute(
-            "SELECT product from cli_data where station = %s and valid = %s",
-            (data["db_station"], data["cli_valid"]),
-        )
-        if cursor.rowcount == 1:
-            row = cursor.fetchone()
-            if self.get_product_id() < row["product"]:
-                return
-            cursor.execute(
-                "DELETE from cli_data WHERE station = %s and valid = %s",
-                (data["db_station"], data["cli_valid"]),
-            )
-        cursor.execute(
-            """INSERT into cli_data(
-        station, product, valid, high, high_normal, high_record,
-        high_record_years, low, low_normal, low_record, low_record_years,
-        precip, precip_month, precip_jan1, precip_jul1, precip_normal,
-        precip_record,
-        precip_record_years, precip_month_normal, snow, snow_month,
-        snow_jun1, snow_jul1,
-        snow_dec1, precip_dec1, precip_dec1_normal, precip_jan1_normal,
-        high_time, low_time, snow_record_years, snow_record,
-        snow_jun1_normal, snow_jul1_normal, snow_dec1_normal,
-        snow_month_normal, precip_jun1, precip_jun1_normal,
-        average_sky_cover,
-        resultant_wind_speed, resultant_wind_direction,
-        highest_wind_speed, highest_wind_direction,
-        highest_gust_speed, highest_gust_direction,
-        average_wind_speed)
-        VALUES (
-        %s, %s, %s, %s, %s, %s,
-        %s, %s, %s, %s, %s,
-        %s, %s, %s, %s, %s,
-        %s,
-        %s, %s, %s, %s,
-        %s, %s,
-        %s, %s, %s, %s,
-        %s, %s, %s, %s,
-        %s, %s, %s, %s, %s, %s,
-        %s,
-        %s, %s,
-        %s, %s,
-        %s, %s,
-        %s
-        )
-        """,
-            (
-                data["db_station"],
-                self.get_product_id(),
-                data["cli_valid"],
-                data["data"].get("temperature_maximum"),
-                data["data"].get("temperature_maximum_normal"),
-                data["data"].get("temperature_maximum_record"),
-                data["data"].get("temperature_maximum_record_years", []),
-                data["data"].get("temperature_minimum"),
-                data["data"].get("temperature_minimum_normal"),
-                data["data"].get("temperature_minimum_record"),
-                data["data"].get("temperature_minimum_record_years", []),
-                data["data"].get("precip_today"),
-                data["data"].get("precip_month"),
-                data["data"].get("precip_jan1"),
-                data["data"].get("precip_jul1"),
-                data["data"].get("precip_today_normal"),
-                data["data"].get("precip_today_record"),
-                data["data"].get("precip_today_record_years", []),
-                data["data"].get("precip_month_normal"),
-                data["data"].get("snow_today"),
-                data["data"].get("snow_month"),
-                data["data"].get("snow_jun1"),
-                data["data"].get("snow_jul1"),
-                data["data"].get("snow_dec1"),
-                data["data"].get("precip_dec1"),
-                data["data"].get("precip_dec1_normal"),
-                data["data"].get("precip_jan1_normal"),
-                data["data"].get("temperature_maximum_time"),
-                data["data"].get("temperature_minimum_time"),
-                data["data"].get("snow_today_record_years", []),
-                data["data"].get("snow_today_record"),
-                data["data"].get("snow_jun1_normal"),
-                data["data"].get("snow_jul1_normal"),
-                data["data"].get("snow_dec1_normal"),
-                data["data"].get("snow_month_normal"),
-                data["data"].get("precip_jun1"),
-                data["data"].get("precip_jun1_normal"),
-                data["data"].get("average_sky_cover"),
-                data["data"].get("resultant_wind_speed"),
-                data["data"].get("resultant_wind_direction"),
-                data["data"].get("highest_wind_speed"),
-                data["data"].get("highest_wind_direction"),
-                data["data"].get("highest_gust_speed"),
-                data["data"].get("highest_gust_direction"),
-                data["data"].get("average_wind_speed"),
-            ),
-        )
-
     def sql(self, cursor):
         """Do the database update!"""
         for entry in self.data:
-            self._sql_data(cursor, entry)
+            sql_data(self, cursor, entry)
             if not update_iemaccess(cursor, entry):
                 self.warnings.append(
                     "IEMAccess Update failed %s %s %s"
