@@ -24,8 +24,8 @@ from pyiem.util import html_escape, LOG
 
 OV_LATLON = re.compile(
     (
-        r"\s?(?P<lat>[0-9]{3,4})(?P<latsign>[NS])"
-        r"\s?(?P<lon>[0-9]{3,5})(?P<lonsign>[EW])"
+        r"\s?(?P<lat>[0-9]{2,4})(?P<latsign>[NS])"
+        r"\s?(?P<lon>[0-9]{2,5})(?P<lonsign>[EW])"
     )
 )
 OV_LOCDIR = re.compile(
@@ -91,6 +91,44 @@ class PilotReport(BaseModel):
     is_duplicate: bool = False
 
 
+def _rectify_identifier(station, textprod):
+    """Rectify the station identifer to IEM Nomenclature."""
+    station = station.strip()
+    if len(station) == 4 and station.startswith("K"):
+        return station[1:]
+    if len(station) == 3 and not textprod.source.startswith("K"):
+        return textprod.source[0] + station
+    return station
+
+
+def _parse_lonlat(text):
+    """Convert string into lon, lat values"""
+    # 2500N07000W
+    # -or- 25N070W -or- 25N70W
+    # FMH-12 says this is in degrees and minutes!
+    d = re.match(OV_LATLON, text).groupdict()
+
+    if len(d["lat"]) == 2 and len(d["lon"]) <= 3:
+        # We have integer values :/
+        lat = int(d["lat"])
+        lon = int(d["lon"])
+    else:
+        # We have Degrees and minutes
+        lat = float(
+            "%s.%i"
+            % (d["lat"][:-2], int(float(d["lat"][-2:]) / 60.0 * 10000.0))
+        )
+        lon = float(
+            "%s.%i"
+            % (d["lon"][:-2], int(float(d["lon"][-2:]) / 60.0 * 10000.0))
+        )
+    if d["latsign"] == "S":
+        lat *= -1
+    if d["lonsign"] == "W":
+        lon *= -1
+    return lon, lat
+
+
 class Pirep(product.TextProduct):
     """ Class for parsing and representing Space Wx Products. """
 
@@ -125,7 +163,7 @@ class Pirep(product.TextProduct):
             if report.strip() == "":
                 continue
             res = self.process_pirep(" ".join(report.strip().split()))
-            if res is not None:
+            if res is not None and res.valid is not None:
                 self.reports.append(res)
 
     def process_pirep(self, report):
@@ -139,7 +177,7 @@ class Pirep(product.TextProduct):
             if i == 0:
                 if len(token) > 10:
                     LOG.info("Aborting as not-PIREP? |%s|", report)
-                    return
+                    return None
                 if token.find(" UUA") > 0:
                     _pr.priority = Priority.UUA
                 else:
@@ -160,99 +198,66 @@ class Pirep(product.TextProduct):
                 bearing = 0
                 therest = token[3:]
                 if len(therest) == 3:
-                    loc = therest
+                    loc = _rectify_identifier(therest, self)
                 elif therest.startswith("FINAL RWY"):
-                    loc = report[:8].split()[0]
-                    if len(loc) == 4 and loc[0] == "K":
-                        loc = loc[1:]
+                    loc = _rectify_identifier(report[:8].split()[0], self)
                 elif len(therest) == 4:
-                    if therest[0] == "K":
-                        loc = therest[1:]
-                    else:
-                        loc = therest
+                    loc = _rectify_identifier(therest, self)
                 elif re.match(OV_OFFSET, therest):
                     d = re.match(OV_OFFSET, therest).groupdict()
-                    loc = d["loc"]
-                    if len(loc) == 4 and loc[0] == "K":
-                        loc = loc[1:]
+                    loc = _rectify_identifier(d["loc"], self)
                     dist = int(d["dist"])
                     bearing = DRCT2DIR[d["dir"]]
-
-                elif re.match(OV_LOCDIR, therest):
-                    # KFAR330008
-                    d = re.match(OV_LOCDIR, therest).groupdict()
-                    loc = d["loc"]
-                    if len(loc) == 4 and loc[0] == "K":
-                        loc = loc[1:]
-                    bearing = int(d["dir"])
-                    dist = int(d["dist"])
-                elif re.match(OV_LATLON, therest):
-                    # 2500N07000W
-                    # FMH-12 says this is in degrees and minutes!
-                    d = re.match(OV_LATLON, therest).groupdict()
-                    _pr.latitude = float(
-                        "%s.%i"
-                        % (
-                            d["lat"][:-2],
-                            int(float(d["lat"][-2:]) / 60.0 * 10000.0),
-                        )
-                    )
-                    if d["latsign"] == "S":
-                        _pr.latitude = 0 - _pr.latitude
-                    _pr.longitude = float(
-                        "%s.%i"
-                        % (
-                            d["lon"][:-2],
-                            int(float(d["lon"][-2:]) / 60.0 * 10000.0),
-                        )
-                    )
-                    if d["lonsign"] == "W":
-                        _pr.longitude = 0 - _pr.longitude
-                    continue
-                elif therest == "O":
-                    # Use the first part of the report in this case
-                    loc = report[:3]
                 elif therest.find("-") > 0 and re.match(OV_TWOLOC, therest):
                     d = re.match(OV_TWOLOC, therest).groupdict()
                     numbers = re.findall("[0-9]{6}", therest)
                     if numbers:
                         bearing = int(numbers[0][:3])
                         dist = int(numbers[0][3:])
-                        loc = d["loc2"]
-                        if len(loc) == 4 and loc[0] == "K":
-                            loc = loc[1:]
+                        loc = _rectify_identifier(d["loc2"], self)
                     else:
                         # Split the distance between the two points
                         lats = []
                         lons = []
                         for loc in [d["loc1"], d["loc2"]]:
-                            if len(loc) == 4 and loc[0] == "K":
-                                loc = loc[1:]
+                            loc = _rectify_identifier(loc, self)
                             if loc not in self.nwsli_provider:
                                 self.warnings.append(
                                     f"Unknown location: {loc} '{report}'"
                                 )
-                                return None
-                            lats.append(self.nwsli_provider[loc]["lat"])
-                            lons.append(self.nwsli_provider[loc]["lon"])
-                        _pr.latitude = sum(lats) / 2.0
-                        _pr.longitude = sum(lons) / 2.0
+                            else:
+                                lats.append(self.nwsli_provider[loc]["lat"])
+                                lons.append(self.nwsli_provider[loc]["lon"])
+                        if len(lats) == 2:
+                            _pr.latitude = sum(lats) / 2.0
+                            _pr.longitude = sum(lons) / 2.0
                         continue
+                elif re.match(OV_LOCDIR, therest):
+                    # KFAR330008
+                    d = re.match(OV_LOCDIR, therest).groupdict()
+                    loc = _rectify_identifier(d["loc"], self)
+                    bearing = int(d["dir"])
+                    dist = int(d["dist"])
+                elif re.match(OV_LATLON, therest):
+                    _pr.longitude, _pr.latitude = _parse_lonlat(therest)
+                    continue
+                elif therest == "O":
+                    # Use the first part of the report in this case
+                    loc = _rectify_identifier(report[:3], self)
                 else:
-                    loc = therest[:3]
+                    loc = _rectify_identifier(therest[:3], self)
 
                 if loc not in self.nwsli_provider:
                     if _pr.base_loc is None:
                         self.warnings.append(
                             f"Unknown location: {loc} '{report}'"
                         )
-                        return None
-                    loc = _pr.base_loc
-                    if loc not in self.nwsli_provider:
-                        self.warnings.append(
-                            f"Double-unknown location: {report}"
-                        )
-                        return None
+                    else:
+                        loc = _pr.base_loc
+                        if loc not in self.nwsli_provider:
+                            self.warnings.append(
+                                f"Double-unknown location: {report}"
+                            )
                     # So we discard the offset when we go back to the base
                     dist = 0
                     bearing = 0
@@ -272,10 +277,12 @@ class Pirep(product.TextProduct):
                 _pr.valid = self.compute_pirep_valid(hour, minute)
                 continue
 
-        return _pr if _pr.latitude is not None else None
+        return _pr
 
     def compute_loc(self, loc, dist, bearing):
         """ Figure out the lon/lat for this location """
+        if loc is None or loc not in self.nwsli_provider:
+            return None, None
         lat = self.nwsli_provider[loc]["lat"]
         lon = self.nwsli_provider[loc]["lon"]
         # shortcut
@@ -305,14 +312,17 @@ class Pirep(product.TextProduct):
         for report in self.reports:
             if report.is_duplicate:
                 continue
+            if report.longitude is None:
+                geom = "POINT EMPTY"
+            else:
+                geom = f"SRID=4326;POINT({report.longitude} {report.latitude})"
             txn.execute(
                 "INSERT into pireps(valid, geom, is_urgent, "
                 "aircraft_type, report) VALUES (%s, "
-                "ST_GeographyFromText('SRID=4326;POINT(%s %s)'),%s,%s,%s)",
+                "ST_GeographyFromText(%s), %s, %s, %s)",
                 (
                     report.valid,
-                    report.longitude,
-                    report.latitude,
+                    geom,
                     report.priority == Priority.UUA,
                     report.aircraft_type,
                     report.text,
@@ -322,23 +332,21 @@ class Pirep(product.TextProduct):
     def assign_cwsu(self, txn):
         """ Use this transaction object to assign CWSUs for the pireps """
         for report in self.reports:
+            if report.latitude is None:
+                continue
             txn.execute(
-                "select distinct id from cwsu WHERE "
+                "select id from cwsu WHERE "
                 "st_contains(geom, geomFromEWKT('SRID=4326;POINT(%s %s)'))",
                 (report.longitude, report.latitude),
             )
-            if txn.rowcount == 0:
-                # self.warnings.append("Find CWSU failed %.3f %.3f %s" % (
-                #    report.longitude, report.latitude, report.text))
-                continue
-            row = txn.fetchone()
-            report.cwsu = row["id"]
+            if txn.rowcount > 0:
+                report.cwsu = txn.fetchone()["id"]
 
     def get_jabbers(self, _uri, _uri2=None):
         """ get jabber messages """
         res = []
         for report in self.reports:
-            if report.is_duplicate or report.valid is None:
+            if report.is_duplicate:
                 continue
             jmsg = {
                 "priority": "Urgent"
@@ -359,13 +367,16 @@ class Pirep(product.TextProduct):
                 "channels": (
                     f"{report.priority}.{report.cwsu},{report.priority}.PIREP"
                 ),
-                "geometry": "POINT(%s %s)"
-                % (report.longitude, report.latitude),
                 "ptype": report.priority,
                 "category": "PIREP",
                 "twitter": plain[:140],
                 "valid": report.valid.strftime("%Y%m%dT%H:%M:00"),
             }
+            if report.latitude is not None:
+                xtra["geometry"] = "POINT(%s %s)" % (
+                    report.longitude,
+                    report.latitude,
+                )
             res.append([plain, html, xtra])
         return res
 
