@@ -399,6 +399,7 @@ class VTECProduct(TextProduct):
         [[plain, html, xtra]] -- A list of triples of plain text, html, xtra
         """
         wfo = self.source[1:]
+        wfo4 = wfo if self.source.startswith("K") else self.source
         if self.skip_con:
             xtra = {
                 "product_id": self.get_product_id(),
@@ -464,6 +465,13 @@ class VTECProduct(TextProduct):
                     "vtec": vtec.get_id(self.db_year),
                     "ptype": vtec.phenomena,
                     "twitter": "",
+                    "twitter_media": (
+                        "https://mesonet.agron.iastate.edu/plotting/auto/plot/"
+                        f"208/network:WFO::wfo:{wfo4}::"
+                        f"year:{self.db_year}::phenomenav:{vtec.phenomena}::"
+                        f"significancev:{vtec.significance}::"
+                        f"etn:{vtec.etn}::valid:"
+                    ),
                 }
 
                 long_actions.append(
@@ -509,14 +517,21 @@ class VTECProduct(TextProduct):
                     jmsg_dict["url"] += "_%s" % (
                         vtec.begints.strftime("%Y-%m-%dT%H:%MZ"),
                     )
+                    xtra["twitter_media"] += vtec.begints.strftime(
+                        "%Y-%m-%d%%20%H%M"
+                    )
                     if vtec.begints > (self.utcnow + timedelta(hours=1)):
                         jmsg_dict["sts"] = " %s " % (
                             vtec.get_begin_string(self),
                         )
                 else:
                     jmsg_dict["url"] += "_%s" % (
-                        self.utcnow.strftime("%Y-%m-%dT%H:%MZ"),
+                        self.valid.strftime("%Y-%m-%dT%H:%MZ"),
                     )
+                    xtra["twitter_media"] += self.valid.strftime(
+                        "%Y-%m-%d%%20%H%M"
+                    )
+                xtra["twitter_media"] += ".png"
                 jmsg_dict["ets"] = vtec.get_end_string(self)
 
                 # Include the special bulletin for Tornado Warnings
