@@ -23,7 +23,6 @@ import os
 import sys
 import subprocess
 import shutil
-import pickle
 import datetime
 import warnings
 
@@ -31,6 +30,8 @@ import warnings
 import rasterio
 from rasterio.warp import reproject, Resampling
 import requests
+from metpy.calc import wind_components
+from metpy.units import units
 import numpy as np
 import pandas as pd
 import geopandas as gpd
@@ -38,7 +39,6 @@ from shapely.geometry import shape
 from scipy.signal import convolve2d
 from scipy.interpolate import NearestNDInterpolator
 from PIL import Image
-from matplotlib.patches import Polygon
 import matplotlib.colors as mpcolors
 from matplotlib.patches import Wedge
 import matplotlib.colorbar as mpcolorbar
@@ -58,6 +58,7 @@ from pyiem.plot.util import (
     fitbox,
 )
 from pyiem.reference import (  # noqa: F401  # pylint: disable=unused-import
+    LATLON,
     Z_CF,
     Z_FILL,
     Z_FILL_LABEL,
@@ -70,10 +71,10 @@ from pyiem.reference import (  # noqa: F401  # pylint: disable=unused-import
     TWITTER_RESOLUTION_INCH,
 )
 from pyiem.util import ssw, LOG, utc, exponential_backoff
-from pyiem.datatypes import speed, direction
 from pyiem.plot.colormaps import stretch_cmap
-import pyiem.meteorology as meteorology
 
+# geopandas currently emits this as parquet is unstable.
+warnings.filterwarnings("ignore", message=".*implementation of Parquet.*")
 # we ran the cartopy/tools downloader
 cartopy.config["pre_existing_data_dir"] = "/opt/miniconda3/cartopy_data/"
 # Set a saner default for apache et al
@@ -85,21 +86,6 @@ MAIN_AX_BOUNDS = [0.01, 0.05, 0.898, 0.85]
 CAX_BOUNDS = [0.917, 0.1, 0.02, 0.8]
 
 
-def true_filter(_bm, _key, _val):
-    """Always return true"""
-    return True
-
-
-def cwa_filter(bm, _key, val):
-    """A filter for checking a key against current plot"""
-    return val.get("cwa", "") == bm.cwa
-
-
-def state_filter(bm, key, _val):
-    """A filter for checking a key against current plot"""
-    return key[:2] == bm.state
-
-
 def load_bounds(filebase):
     """Load bounds file
 
@@ -132,23 +118,20 @@ def load_pickle_pd(filename):
     return pd.read_pickle(fn)
 
 
-def load_pickle_geo(filename):
-    """Load pickled dictionaries containing geometries and other metadata
+def load_geodf(filename):
+    """Load GeoPandas GeoDataFrame.
 
     Args:
       filename(str): The filename to load, contained in project data/
 
     Returns:
-      dict: The dictionary of data
+      GeoDataFrame
     """
-    fn = "%s/%s" % (DATADIR, filename)
+    fn = "%s/geodf/%s.parquet" % (DATADIR, filename)
     if not os.path.isfile(fn):
-        LOG.info("load_pickle_geo(%s) failed, file is missing!", fn)
-        return dict()
-    pickle_opts = dict()
-    if sys.version_info.major > 2:
-        pickle_opts["encoding"] = "bytes"
-    return pickle.load(open(fn, "rb"), **pickle_opts)
+        LOG.info("load_geodf(%s) failed, file is missing!", fn)
+        return gpd.GeoDataFrame()
+    return gpd.read_parquet(fn)
 
 
 class MapPlot:
@@ -233,9 +216,9 @@ class MapPlot:
                 cfeature.LAKES, facecolor=(0.4471, 0.6235, 0.8117), zorder=Z_CF
             )
             if "nostates" not in kwargs:
-                states = load_pickle_geo("us_states.pickle")
+                states = load_geodf("us_states")
                 _a.add_geometries(
-                    [val["geom"] for key, val in states.items()],
+                    states["geom"].values,
                     crs=ccrs.PlateCarree(),
                     lw=1.0,
                     edgecolor=kwargs.get("statebordercolor", "k"),
@@ -554,12 +537,12 @@ class MapPlot:
             mask[imgx - 15 : imgx + 15, imgy - 15 : imgy + 15] = True
             # Plot bars
             if stdata.get("sknt") is not None and stdata["sknt"] > 1:
-                (u, v) = meteorology.uv(
-                    speed(stdata.get("sknt", 0), "KT"),
-                    direction(stdata.get("drct", 0), "DEG"),
+                (u, v) = wind_components(
+                    units("knot") * stdata["sknt"],
+                    units("degree") * stdata["drct"],
                 )
                 if u is not None and v is not None:
-                    self.ax.barbs(x, y, u.value("KT"), v.value("KT"), zorder=1)
+                    self.ax.barbs(x, y, u.m, v.m, zorder=Z_OVERLAY)
 
             # Sky Coverage
             skycoverage = stdata.get("coverage")
@@ -699,19 +682,29 @@ class MapPlot:
         if self.textmask is None:
             # zorder is used to track plotting priorities
             self.textmask = np.zeros((int(figwidth), int(figheight)), np.int8)
-        thisax = self.ax
         # Create a fake label, to test out our scaling
         t0 = self.fig.text(
             0.5,
             0.5,
             "ABCDEFGHIJ",
-            transform=thisax.transAxes,
+            transform=self.ax.transAxes,
             color="None",
             size=textsize,
         )
         bbox = t0.get_window_extent(self.fig.canvas.get_renderer())
         xpixels_per_char = bbox.width / 10.0
         ypixels = bbox.height
+
+        def _find_ax(lon, lat):
+            """Figure out whom this point belongs."""
+            for ax in self.axes:
+                (x0, x1, y0, y1) = ax.get_extent()
+                (x, y) = ax.projection.transform_point(
+                    lon, lat, ccrs.Geodetic()
+                )
+                if (x0 <= x <= x1) and (y0 <= y <= y1):
+                    return ax
+
         for o, a, v, m, c, label, z in zip(
             lons, lats, vals, valmask, color, labels, zorder
         ):
@@ -723,8 +716,11 @@ class MapPlot:
             max_mystr_len = max([len(s) for s in mystr.split("\n")])
             mystr_lines = len(mystr.split("\n"))
             # compute the pixel coordinate of this data point
-            (x, y) = thisax.projection.transform_point(o, a, ccrs.Geodetic())
-            (imgx, imgy) = thisax.transData.transform([x, y])
+            ax = _find_ax(o, a)
+            if ax is None:
+                continue
+            (x, y) = ax.projection.transform_point(o, a, ccrs.Geodetic())
+            (imgx, imgy) = ax.transData.transform([x, y])
             imgx0 = int(imgx - (max_mystr_len * xpixels_per_char / 2.0))
             if imgx0 < axx0:
                 ha = "left"
@@ -804,7 +800,7 @@ class MapPlot:
                     int(imgx0) : int(imgx1), int(imgy0) : int(imgy1)
                 ],
             )
-            t0 = thisax.text(
+            t0 = ax.text(
                 o,
                 a,
                 mystr,
@@ -826,7 +822,7 @@ class MapPlot:
                 )
                 self.fig.patches.append(rec)
             if showmarker:
-                thisax.scatter(
+                ax.scatter(
                     o,
                     a,
                     marker="+",
@@ -846,7 +842,7 @@ class MapPlot:
             )
 
             if label and label != "":
-                thisax.annotate(
+                ax.annotate(
                     "%s" % (label,),
                     xy=(x, y),
                     ha="center",
@@ -970,20 +966,20 @@ class MapPlot:
             return
         # in lon,lat
         if sector == "state":
-            s = load_pickle_geo("us_states.pickle")
-            mask_outside_geom(self.ax, s[self.state]["geom"])
+            s = load_geodf("us_states")
+            mask_outside_geom(self.ax, s.at[self.state, "geom"])
             return
         if sector == "cwa":
-            s = load_pickle_geo("cwa.pickle")
-            mask_outside_geom(self.ax, s[self.cwa]["geom"])
+            s = load_geodf("cwa")
+            mask_outside_geom(self.ax, s.at[self.cwa, "geom"])
             return
         if sector == "conus":
-            s = load_pickle_geo("conus.pickle")
-            mask_outside_geom(self.ax, s["conus"]["geom"])
+            s = load_geodf("conus")
+            mask_outside_geom(self.ax, s.iloc[0]["geom"])
             return
         if sector == "iowawfo":
-            s = load_pickle_geo("iowawfo.pickle")
-            geo = s["iowawfo"]["geom"]
+            s = load_geodf("iowawfo")
+            geo = s["geom"].values[0]
             ccw = np.asarray(geo.exterior)[::-1]
         else:
             ccw = load_bounds("%s_ccw" % (sector,))
@@ -1102,16 +1098,11 @@ class MapPlot:
 
         Args:
           data (dict): A dictionary of climate division IDs and values
-          bins (optional[list]): a list of values for classification
-          lblformat (optional[str]): a format specifier to use
-          **kwargs (optional): other values
         """
-        clidict = load_pickle_geo("climdiv.pickle")
-        polygon_fill(self, clidict, data, **kwargs)
+        geodf = load_geodf("climdiv")
+        polygon_fill(self, geodf, data, **kwargs)
 
-    def fill_ugcs(
-        self, data, bins=None, color=None, is_firewx=False, **kwargs
-    ):
+    def fill_ugcs(self, data, **kwargs):
         """Overlay filled UGC geometries
 
         Note the importance of the `is_firewx` flag.  This determines which
@@ -1130,94 +1121,24 @@ class MapPlot:
           missingval(str, optional): value to use when labelling UGCs with
             missing values, defaults to '-'.
         """
-        if bins is None:
-            bins = np.arange(0, 101, 10)
-        cmap = stretch_cmap(
-            kwargs.get("cmap"), bins, extend=kwargs.get("extend")
-        )
-        norm = mpcolors.BoundaryNorm(bins, cmap.N)
         # Figure out if we have zones or counties/parishes
         counties = True
         for key in data:
             if key[2] == "Z":
                 counties = False
             break
-        zonesfn = "firewx" if is_firewx else "zone"
-        ugcs = load_pickle_geo(
-            "ugcs_county.pickle" if counties else f"ugcs_{zonesfn}.pickle"
-        )
-        if color is None:
-            color = dict()
-        filter_func = true_filter
+        zonesfn = "firewx" if kwargs.get("is_firewx", False) else "zone"
+        geodf = load_geodf("ugcs_county" if counties else f"ugcs_{zonesfn}")
         if self.sector == "state":
-            filter_func = state_filter
+            geodf = geodf[geodf.index.str.slice(0, 2) == self.state]
         elif self.sector == "cwa":
-            filter_func = cwa_filter
-        ilabel = kwargs.get("ilabel", False)
-        plotmissing = kwargs.get("plotmissing", True)
-        labels = kwargs.get("labels", dict())
-        to_label = {"x": [], "y": [], "vals": [], "zorder": []}
-        for ugc in ugcs:
-            ugcdict = ugcs[ugc]
-            if not filter_func(self, ugc, ugcdict):
-                continue
-            if data.get(ugc) is None:
-                if not plotmissing:
-                    continue
-                c = "white"
-                val = kwargs.get("missingval", "-")
-                z = Z_OVERLAY
-            else:
-                val = data[ugc]
-                c = color.get(ugc, cmap(norm([val]))[0])
-                z = Z_OVERLAY2
-            for polyi, polygon in enumerate(ugcdict.get("geom", [])):
-                if polygon.exterior is None:
-                    continue
-                if z in [Z_OVERLAY, Z_OVERLAY2]:
-                    arr = np.asarray(polygon.exterior)
-                    # Figure out which ax this goes with
-                    ax = self.ax
-                    if self.sector == "nws":
-                        if ugc.startswith("PR"):
-                            ax = self.pr_ax
-                        elif ugc.startswith("AK"):
-                            ax = self.ak_ax
-                        elif ugc.startswith("HI"):
-                            ax = self.hi_ax
-                    points = ax.projection.transform_points(
-                        ccrs.Geodetic(), arr[:, 0], arr[:, 1]
-                    )
-                    ax.add_patch(
-                        Polygon(points[:, :2], fc=c, ec="k", zorder=z, lw=0.1)
-                    )
-                if polyi == 0 and ilabel:
-                    # prefer our stored centroid vs calculated one
-                    mx = ugcdict.get("lon", polygon.centroid.x)
-                    my = ugcdict.get("lat", polygon.centroid.y)
-                    to_label["x"].append(mx)
-                    to_label["y"].append(my)
-                    to_label["vals"].append("%s" % (labels.get(ugc, val),))
-                    to_label["zorder"].append(z + 1)
-        if to_label:
-            self.plot_values(
-                to_label["x"],
-                to_label["y"],
-                to_label["vals"],
-                zorder=to_label["zorder"],
-                labelbuffer=kwargs.get("labelbuffer", 1),
-                textsize=12,
-                textoutlinewidth=2,
-            )
-        if "cmap" in kwargs:
-            del kwargs["cmap"]
-        if not kwargs.get("nocbar", False):
-            self.draw_colorbar(bins, cmap, norm, **kwargs)
+            geodf = geodf[geodf["cwa"] == self.cwa]
+        polygon_fill(self, geodf, data, **kwargs)
 
     def fill_states(self, data, **kwargs):
         """Add overlay of filled state polygons"""
-        states = load_pickle_geo("us_states.pickle")
-        polygon_fill(self, states, data, **kwargs)
+        geodf = load_geodf("us_states")
+        polygon_fill(self, geodf, data, **kwargs)
 
     def draw_cwas(self, color="k", **kwargs):
         """Overlay CWA Borders
@@ -1229,10 +1150,10 @@ class MapPlot:
           kwargs(dict, optional): Parameters passed to matplotlib for plotting
         """
         kwargs["edgecolor"] = color
-        cwas = load_pickle_geo("cwa.pickle")
+        cwas = load_geodf("cwa")
         for _a in self.axes:
             _a.add_geometries(
-                [val["geom"] for key, val in cwas.items()],
+                cwas["geom"].values,
                 crs=ccrs.PlateCarree(),
                 zorder=Z_POLITICAL,
                 facecolor="None",
@@ -1250,21 +1171,13 @@ class MapPlot:
           data (dict): Dictionary of values with keys representing the 3 char
             or 4 char idenitifer for the WFO.  This assumes the 3 char sites
             are the K ones.
-          labels (dict, optional): Optional dictionary that follows the
-            ``data`` attribute, but hard codes what should be plotted as a
-            label.
-          bins (list, optional): List of increasing values to use as bins to
-            determine color levels.
-          lblformat (str, optional): Format string to use to place labels.
-          cmap (matplotlib.cmap, optional): Colormap to use with ``bins``
-
         """
-        cwas = load_pickle_geo("cwa.pickle")
+        geodf = load_geodf("cwa")
         # Painfull.  San Juan's WFO identifier is SJU, but VTEC uses JSJ, our
         # plotting here uses SJU
         if "JSJ" in data:
             data["SJU"] = data["JSJ"]
-        polygon_fill(self, cwas, data, **kwargs)
+        polygon_fill(self, geodf, data, **kwargs)
 
     def drawcities(self, **kwargs):
         """Overlay some cities
@@ -1310,13 +1223,9 @@ class MapPlot:
         Args:
           color (color,optional): line color to use
         """
-        ugcdict = load_pickle_geo("ugcs_county.pickle")
-        polys = []
-        for ugc in ugcdict:
-            for polygon in ugcdict[ugc].get("geom", []):
-                polys.append(polygon)
+        geodf = load_geodf("ugcs_county")
         self.ax.add_geometries(
-            polys,
+            geodf["geom"].values,
             crs=ccrs.PlateCarree(),
             facecolor="None",
             edgecolor=color,
@@ -1346,8 +1255,8 @@ class MapPlot:
             im2.save(ram, format="png")
             ram.seek(0)
             r = ram.read()
-            kwargs.get("memcache").set(
-                kwargs.get("memcachekey"),
+            kwargs["memcache"].set(
+                kwargs["memcachekey"],
                 r,
                 time=kwargs.get("memcacheexpire", 300),
             )
