@@ -90,10 +90,12 @@ def html_escape(val):
     return escape(val)
 
 
-def get_test_file(name, fponly=False):
+def get_test_file(name, fponly=False, fnonly=False):
     """Helper to get data for test usage."""
     basedir = os.path.dirname(__file__)
     fn = f"{basedir}/../../data/product_examples/{name}"
+    if fnonly:
+        return fn
     fp = open(fn, "rb")
     if fponly:
         return fp
@@ -383,7 +385,7 @@ def get_autoplot_context(fdict, cfg):
             if default is not None:
                 default = float(default)
         elif typ == "select":
-            options = opt.get("options", dict())
+            options = opt.get("options", {})
             # in case of multi, value could be a list
             if value is None:
                 value = default
