@@ -11,6 +11,7 @@ NWSLI_PROVIDER = {
     "KIAD": dict(name="HOUSTON INTERCONTINENTAL", access_network="ZZ_ASOS"),
     "KDMH": dict(name="", attributes={"MAPS_TO": "QQQ|ZZ_ASOS"}),
     "KHOU": dict(name="HOUSTON/HOBBY AIRPORT", access_network="ZZ_ASOS"),
+    "KRDU": dict(name="RALEIGH-DURHAM", access_network="NC_ASOS"),
     "PADQ": dict(name="KODIAK", access_network="AK_ASOS"),
     "PAKN": dict(name="KING SALMON", access_network="AK_ASOS"),
     "PANC": dict(name="ANCHORAGE AK", access_network="AK_ASOS"),
@@ -26,11 +27,54 @@ def factory(fn):
     return cliparser(get_test_file(fn), nwsli_provider=NWSLI_PROVIDER)
 
 
+def test_clirdu():
+    """Test handling of another CLI variant."""
+    text = get_test_file("CLI/CLIRDU_v2.txt")
+    prod = cliparser(text)
+    assert prod.data[0]["data"].get("temperature_maximum") == 57
+
+
+def test_invalid_temperature_year_second_line():
+    """Test that we don't allow an invalid year in the second line."""
+    text = get_test_file("CLI/CLIEKA.txt")
+    text = text.replace("    1978    ", "    9999    ")
+    prod = cliparser(text)
+    assert "9999" in prod.warnings[1]
+
+
+def test_invalid_temperature_year():
+    """Test that we don't allow an invalid year."""
+    text = get_test_file("CLI/CLIRDU.txt")
+    text = text.replace("1945  64", " 945  64")
+    prod = cliparser(text)
+    assert prod.data[0]["data"].get("temperature_maximum_record_years") is None
+
+
+def test_issue408_estimated():
+    """Test that we catch some GIO with estimated temperature flag."""
+    prod = factory("CLI/CLIRDU.txt")
+    assert prod.warnings[0].find("repaired") > -1
+    assert prod.data[0]["data"]["temperature_maximum_record_years"][0] == 1945
+
+
+@pytest.mark.parametrize("database", ["iem"])
+def test_issue396_snow_normal(dbcursor):
+    """See that snow_normal goes to the database."""
+    prod = cliparser(get_test_file("CLI/CLICVG_colon.txt"))
+    prod.sql(dbcursor)
+    dbcursor.execute(
+        "SELECT snow_normal from cli_data where station = 'KCVG' and "
+        "valid = '2021-02-04'"
+    )
+    assert abs(dbcursor.fetchone()[0] - 0.2) < 0.01
+
+
 def test_210206_colon():
     """Test that we can handle colons in the timestamp."""
     prod = cliparser(get_test_file("CLI/CLICVG_colon.txt"))
     assert prod.data[0]["data"]["temperature_maximum"] == 39
     assert prod.data[0]["data"]["temperature_maximum_normal"] == 40
+    assert prod.data[0]["data"]["snow_today_normal"] == 0.2
 
 
 def test_wrong_wmo_header():
@@ -162,11 +206,16 @@ def test_180208_issue56_tweetmissing():
     prod = factory("CLI/CLIFFC.txt")
     j = prod.get_jabbers("http://localhost", "http://localhost")
     ans = (
-        "PEACHTREE CITY Oct 3 Climate: Hi: 79 Lo: 67 Precip: 0.87 "
+        "PEACHTREE CITY Oct 3 Climate: High: 79 Low: 67 Precip: 0.87 "
         "Snow: Missing "
         "http://localhost?pid=201410032032-KFFC-CDUS42-CLIFFC"
     )
     assert j[0][2]["twitter"] == ans
+    ans = (
+        "https://mesonet.agron.iastate.edu/plotting/auto/plot/218/"
+        "network:NWSCLI::station:KFFC::date:2014-10-03.png"
+    )
+    assert j[0][2]["twitter_media"] == ans
 
 
 def test_170530_none():
@@ -332,8 +381,8 @@ def test_141013_tracetweet():
     prod = factory("CLI/CLIDSM2.txt")
     j = prod.get_jabbers("http://localhost", "http://localhost")
     ans = (
-        "DES MOINES IA Oct 12 Climate: Hi: 56 "
-        "Lo: 43 Precip: Trace Snow: 0.0"
+        "DES MOINES IA Oct 12 Climate: High: 56 "
+        "Low: 43 Precip: Trace Snow: 0.0"
         " http://localhost?pid=201410122226-KDMX-CDUS43-CLIDSM"
     )
     assert j[0][2]["twitter"] == ans
