@@ -2,13 +2,7 @@
 
 import pytest
 from pyiem.nws.products.nldn import parser
-from pyiem.util import get_test_file, get_dbconn
-
-
-@pytest.fixture
-def cursor():
-    """Return a database cursor."""
-    return get_dbconn("nldn").cursor()
+from pyiem.util import get_test_file
 
 
 def test_1_basic():
@@ -17,7 +11,8 @@ def test_1_basic():
     assert len(np.df.index) == 50
 
 
-def test_sql(cursor):
+@pytest.mark.parametrize("database", ["nldn"])
+def test_sql(dbcursor):
     """Test that we can insert data."""
     np = parser(get_test_file("NLDN/example.bin", fponly=True))
-    np.sql(cursor)
+    np.sql(dbcursor)
