@@ -7,7 +7,6 @@ import copy
 import pytest
 import matplotlib.colors as mpcolors
 import numpy as np
-from pyiem import reference
 from pyiem import plot
 from pyiem.plot.geoplot import windrose
 from pyiem.plot import (
@@ -16,7 +15,7 @@ from pyiem.plot import (
     pretty_bins,
     load_bounds,
     load_pickle_pd,
-    load_pickle_geo,
+    load_geodf,
 )
 from pyiem.util import utc
 
@@ -31,7 +30,46 @@ def test_invalid_file():
     """Test that we don't error out on an invalid filename."""
     assert load_bounds("this shall not work") is None
     assert load_pickle_pd("this shall not work") is None
-    assert not load_pickle_geo("this shall not work")
+    assert load_geodf("this shall not work").empty
+
+
+@pytest.mark.mpl_image_compare(tolerance=0.1)
+def test_plotmissing():
+    """Test that we can plotmissing."""
+    mp = MapPlot(
+        nocaption=True,
+        sector="cwa",
+        cwa="FSD",
+        title="Testing plotmissing",
+    )
+    mp.fill_climdiv({"IAC001": 10}, plotmissing=False)
+    return mp.fig
+
+
+@pytest.mark.mpl_image_compare(tolerance=0.1)
+def test_fill_by_str():
+    """Test that we can fill by string or dict."""
+    mp = MapPlot(
+        nocaption=True,
+        sector="state",
+        state="CA",
+        title="Testing color provision",
+    )
+    mp.fill_climdiv({"CAC001": 10}, color="b", plotmissing=False)
+    return mp.fig
+
+
+@pytest.mark.mpl_image_compare(tolerance=0.1)
+def test_fill_by_dict():
+    """Test that we can fill by string or dict."""
+    mp = MapPlot(
+        nocaption=True,
+        sector="state",
+        state="CA",
+        title="Testing color provision",
+    )
+    mp.fill_climdiv({"CAC001": 10}, color={"CAC001": "r"}, plotmissing=False)
+    return mp.fig
 
 
 @pytest.mark.mpl_image_compare(tolerance=0.1)
@@ -225,8 +263,9 @@ def test_fill_ugcs_color():
         sector="cwa", cwa="DMX", title="Three Counties", nocaption=True
     )
     data = {"IAC001": 10, "IAC003": 20, "IAC135": 30}
-    color = {"IAC001": "#FF0000", "IAC003": "black"}
-    mp.fill_ugcs(data, color=color, nocbar=True)
+    fc = {"IAC001": "#FF0000", "IAC003": "black"}
+    ec = {}
+    mp.fill_ugcs(data, fc=fc, ec=ec, nocbar=True)
     return mp.fig
 
 
@@ -276,7 +315,6 @@ def test_pcolormesh():
         east=-80,
         west=-96,
         south=38,
-        projection=reference.EPSG[2163],
         continentalcolor="white",
         nocaption=True,
     )
@@ -290,40 +328,6 @@ def test_pcolormesh():
     return mp.fig
 
 
-@pytest.mark.mpl_image_compare(tolerance=0.3)
-def test_conus():
-    """See if we can plot albers"""
-    mp = MapPlot(
-        sector="custom",
-        title="EPSG: 5070 Albers",
-        north=reference.CONUS_NORTH + 1,
-        east=reference.CONUS_EAST - 12,
-        west=reference.CONUS_WEST + 14,
-        south=reference.CONUS_SOUTH,
-        projection=reference.EPSG[5070],
-        continentalcolor="white",
-        nocaption=True,
-    )
-    return mp.fig
-
-
-@pytest.mark.mpl_image_compare(tolerance=0.3)
-def test_conus2():
-    """Map the conus in LEA"""
-    mp = MapPlot(
-        sector="custom",
-        title="EPSG: 2163 Lambert Azimuthal Equal Area",
-        north=reference.CONUS_NORTH + 1,
-        east=reference.CONUS_EAST - 12,
-        west=reference.CONUS_WEST + 14,
-        south=reference.CONUS_SOUTH,
-        projection=reference.EPSG[2163],
-        continentalcolor="white",
-        nocaption=True,
-    )
-    return mp.fig
-
-
 def test_pretty_bins():
     """Test that we get nice pretty bins!"""
     a = pretty_bins(-1, 10)
@@ -419,7 +423,7 @@ def test_fillstates():
         subtitle="test_fillstates",
         nocaption=True,
     )
-    mp.fill_states(data, ilabel=True)
+    mp.fill_states(data, lblformat="%.0f", ilabel=True)
     return mp.fig
 
 
@@ -459,7 +463,7 @@ def test_climdiv():
     """Run tests agains the fill_climdiv"""
     mp = MapPlot(sector="conus", title="Climate Divisions", nocaption=True)
     data = {"IAC001": 10, "MNC001": 20, "NMC001": 30}
-    mp.fill_climdiv(data, ilabel=True)
+    mp.fill_climdiv(data, ilabel=True, lblformat="%.0f")
     return mp.fig
 
 
@@ -536,7 +540,8 @@ def test_drawugcs2():
         subtitle="test_drawugcs2",
         nocaption=True,
     )
-    mp.fill_ugcs({"IAZ001": 10, "IAZ003": 20, "IAZ005": 30}, ilabel=True)
+    mydict = {"IAZ001": 10, "IAZ003": 20, "IAZ005": 30}
+    mp.fill_ugcs(mydict, ilabel=True, lblformat="%.0f")
     return mp.fig
 
 
@@ -567,7 +572,7 @@ def test_ugcs_lwx_zones():
     mp = MapPlot(
         sector="cwa",
         cwa="LWX",
-        title="Two Maryland Zones that Should not be plotted",
+        title="Two Maryland zones (MDZ001, MDZ008) xfered to LWX",
         subtitle="test_ugcs_lwx",
         nocaption=True,
     )
@@ -603,20 +608,12 @@ def test_ugcs_withcustomlabels():
         ilabel=True,
         clevstride=12,
         clevlabels=clevlabels,
+        lblformat="%.0f",
         extend="neither",
     )
     return mp.fig
 
 
-def test_filter_functions():
-    """Make sure our filter functions are doing what we want!"""
-    mp = MapPlot(sector="iowa")
-    assert plot.state_filter(mp, "IAC001", dict())
-    assert not plot.state_filter(mp, "MNC001", dict())
-    mp = MapPlot(cwa="DMX")
-    assert plot.state_filter(mp, "IAC001", dict())
-
-
 @pytest.mark.mpl_image_compare(tolerance=0.15)
 def test_states():
     """Exercise the state plotting routines"""
@@ -778,6 +775,7 @@ def test_plot2():
         {"DMX": 80, "MKX": 5, "SJU": 30, "AJK": 40, "HFO": 50},
         units="NWS Something or Another",
         ilabel=True,
+        lblformat="%.0f",
     )
     return mp.fig
 
@@ -789,6 +787,7 @@ def test_plot22():
     mp.fill_cwas(
         {"DMX": 80, "MKX": 5, "SJU": 30, "AJK": 40, "HFO": 50},
         units="NWS Something or Another",
+        lblformat="%.0f",
     )
     return mp.fig
 
